@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ImportExportProgressIndicatorConsole : public ImportExportProgressIndicato
     Q_OBJECT
 public:
     explicit ImportExportProgressIndicatorConsole(QObject *parent = nullptr);
-    ~ImportExportProgressIndicatorConsole();
+    ~ImportExportProgressIndicatorConsole() override;
 
 private:
     void setProgressDialogLabel(const QString &text) override;
