@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,11 +34,11 @@ class ImportMailJob : public AbstractImportExportJob
     Q_OBJECT
 public:
     explicit ImportMailJob(QObject *widget, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportMailJob();
+    ~ImportMailJob() override;
 
     void start() override;
 
-protected Q_SLOTS:
+protected:
     void slotNextStep() override;
 
 private:
